#!/bin/sh

# Set this environment variable in the Jenkins job to "true"
if [ "$TAG_RELEASE" ]; then
    # Get latest tags
    git pull --tags

    # Get Git Version
    VERSION=`git describe --abbrev=0 --tags`
    VERSION_BITS=(${VERSION//./ })

    if [ ! -z "$MAJOR_VERSION" ]; then
        MAJOR="v$MAJOR_VERSION"
    else
        MAJOR=${VERSION_BITS[0]}
    fi

    if [ ! -z "$MINOR_VERSION" ]; then
        MINOR="$MINOR_VERSION"
    else
        MINOR=${VERSION_BITS[1]}
    fi

    # If the major or minor version have been updated set the patch version to 0, otherwise incremenet.
    if [ "v$MAJOR_VERSION" != ${VERSION_BITS[0]} ] || [ "$MINOR_VERSION" != ${VERSION_BITS[1]} ]; then
        NEW_PATCH="0"
    else
        PATCH=${VERSION_BITS[2]}
        NEW_PATCH=$((PATCH+1))
    fi

    NEW_TAG="$MAJOR.$MINOR.$NEW_PATCH"
    echo "Updating $VERSION to $NEW_TAG"
    #Check if we have a tag on this commit
    GIT_COMMIT=`git rev-parse HEAD`
    NEEDS_TAG=`git describe --contains $GIT_COMMIT 2>/dev/null`

    #only tag if no tag already
    if [ -z "$NEEDS_TAG" ]; then
        echo "Updating $VERSION to $NEW_TAG"
        git tag -a $NEW_TAG -m "$NEW_TAG"
        echo "Tagged with $NEW_TAG"
        git push --tags
    else
        echo "Already a tag on this commit / not ran in Jenkins"
    fi
fi

# Make sure the build directory exists.
mkdir -p ./build/dist

# Build schematics
npm run build

# Create an npm package and set the version based on the current git tag.
npm version $(git describe --tags --abbrev=0) --no-git-tag-version --allow-same-version
npm pack

# Rename and copy the package to the jar build/dist directory.
mv *.tgz sas-svi-solution-extension-angular-schematics.tgz
cp sas-svi-solution-extension-angular-schematics.tgz ./build/dist

npm publish ./build/dist/sas-svi-solution-extension-angular-schematics.tgz
